@@ -2,9 +2,7 @@
 //
 // The cart slot widget.
 //
-//   (C) Copyright 2012-2014 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdcartslot.cpp,v 1.13.2.19.2.2 2014/06/24 18:27:03 cvs Exp $
+//   (C) Copyright 2012-2014,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -625,9 +623,10 @@ unsigned RDCartSlot::SelectCart(const QString &svcname,unsigned msecs)
     "(SERVICE=\""+RDEscapeString(svcname)+"\")";
   q=new RDSqlQuery(sql);
   while(q->next()) {
-    if(::abs(msecs-q->value(1).toInt())<diff) {
+    int cur_diff = msecs-q->value(1).toInt();
+    if(::abs(cur_diff)<diff) {
       cartnum=q->value(0).toUInt();
-      diff=::abs(msecs-q->value(1).toInt());
+      diff=::abs(cur_diff);
     }
   }
   delete q;
@@ -671,6 +670,8 @@ void RDCartSlot::LogPlayout(RDPlayDeck::State state)
     datetime.setDate(datetime.date().addDays(-1));
   }
   if(!slot_svcname.isEmpty()) {
+    QDateTime eventDateTime(datetime.date(), 
+          slot_logline->startTime(RDLogLine::Actual));
     QString svctablename=slot_svcname;
     svctablename.replace(" ","_");
     sql=QString("insert into `")+svctablename+"_SRT` set "+
@@ -688,17 +689,18 @@ void RDCartSlot::LogPlayout(RDPlayDeck::State state)
 			slot_logline->usageCode(),
 			slot_logline->startSource())+
       "STATION_NAME=\""+RDEscapeString(slot_station->name())+"\","+
-      "EVENT_DATETIME=\""+datetime.toString("yyyy-MM-dd")+
-      " "+slot_logline->startTime(RDLogLine::Actual).toString("hh:mm:ss")+"\","+
-      "EXT_START_TIME=\""+slot_logline->extStartTime().toString("hh:mm:ss")+"\","+
+      "EVENT_DATETIME="+RDCheckDateTime(eventDateTime,"yyyy-MM-dd hh:mm:ss")+
+      ","+
+      "EXT_START_TIME="+RDCheckDateTime(
+                 slot_logline->extStartTime(),"hh:mm:ss")+","+
       "EXT_DATA=\""+RDEscapeString(slot_logline->extData())+"\","+
       "EXT_EVENT_ID=\""+RDEscapeString(slot_logline->extEventId())+"\","+
       "EXT_ANNC_TYPE=\""+RDEscapeString(slot_logline->extAnncType())+"\","+
       "EXT_CART_NAME=\""+RDEscapeString(slot_logline->extCartName())+"\","+
       "TITLE=\""+RDEscapeString(slot_logline->title())+"\","+
       "ARTIST=\""+RDEscapeString(slot_logline->artist())+"\","+
-      "SCHEDULED_TIME=\""+slot_logline->startTime(RDLogLine::Logged).
-      toString("hh:mm:ss")+"\","+
+      "SCHEDULED_TIME="+
+      RDCheckDateTime(slot_logline->startTime(RDLogLine::Logged),"hh:mm:ss")+","+
       "ISRC=\""+RDEscapeString(slot_logline->isrc())+"\","+
       "PUBLISHER=\""+RDEscapeString(slot_logline->publisher())+"\","+
       "COMPOSER=\""+RDEscapeString(slot_logline->composer())+"\","+
