@@ -2,9 +2,7 @@
 //
 //   An flashing button widget.
 //
-//   (C) Copyright 2002 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: rdmarker_edit.h,v 1.5 2007/09/14 14:06:24 fredg Exp $
+//   (C) Copyright 2002,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,7 +17,6 @@
 //   License along with this program; if not, write to the Free Software
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-//
 
 #ifndef RDMARKEREDIT_H
 #define RDMARKEREDIT_H
@@ -29,14 +26,13 @@
 #include <qpixmap.h>
 #include <qcolor.h>
 
-
 class RDMarkerEdit : public QLineEdit
 {
   Q_OBJECT
 
  public:
-  RDMarkerEdit(QWidget *parent,const char *name);
-  RDMarkerEdit(const QString &contents,QWidget *parent,const char *name);
+  RDMarkerEdit(QWidget *parent);
+  RDMarkerEdit(const QString &contents,QWidget *parent);
 
  signals:
   void escapePressed();
