@@ -2,9 +2,7 @@
 //
 // Select a Rivendell Log
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: list_logs.cpp,v 1.7 2008/04/01 20:51:41 grauf Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -25,9 +23,8 @@
 #include <list_logs.h>
 #include <globals.h>
 
-
-ListLogs::ListLogs(QString *logname,QWidget *parent,const char *name)
-  : QDialog(parent,name,true)
+ListLogs::ListLogs(QString *logname,QWidget *parent)
+  : QDialog(parent,"",true)
 {
   //
   // Fix the Window Size
@@ -50,7 +47,7 @@ ListLogs::ListLogs(QString *logname,QWidget *parent,const char *name)
   //
   // Log List
   //
-  list_log_list=new QListView(this,"list_log_list");
+  list_log_list=new QListView(this);
   list_log_list->setGeometry(10,10,
 			    sizeHint().width()-20,sizeHint().height()-80);
   list_log_list->setAllColumnsShowFocus(true);
@@ -69,7 +66,7 @@ ListLogs::ListLogs(QString *logname,QWidget *parent,const char *name)
   //
   // Load Button
   //
-  QPushButton *button=new QPushButton(this,"load_button");
+  QPushButton *button=new QPushButton(this);
   button->setGeometry(10,sizeHint().height()-60,80,50);
   button->setFont(button_font);
   button->setText(tr("&OK"));
@@ -78,7 +75,7 @@ ListLogs::ListLogs(QString *logname,QWidget *parent,const char *name)
   //
   // Cancel Button
   //
-  button=new QPushButton(this,"cancel_button");
+  button=new QPushButton(this);
   button->setGeometry(sizeHint().width()-90,sizeHint().height()-60,80,50);
   button->setFont(button_font);
   button->setText(tr("&Cancel"));
