@@ -2,9 +2,7 @@
 //
 // Select a Rivendell Log
 //
-//   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: list_logs.h,v 1.3 2007/02/14 21:55:07 fredg Exp $
+//   (C) Copyright 2002-2004,2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -28,13 +26,12 @@
 #include <qlistview.h>
 #include <qpushbutton.h>
 
-
 class ListLogs : public QDialog
 {
   Q_OBJECT
 
  public:
-  ListLogs(QString *logname,QWidget *parent=0,const char *name=0);
+  ListLogs(QString *logname,QWidget *parent=0);
   QSize sizeHint() const;
   QSizePolicy sizePolicy() const;
 
