@@ -2,9 +2,7 @@
 //
 // Rivendell web service portal -- Cart services
 //
-//   (C) Copyright 2010 Fred Gleason <fredg@paravelsystems.com>
-//
-//      $Id: carts.cpp,v 1.3 2010/09/08 20:38:01 cvs Exp $
+//   (C) Copyright 2010-2016 Fred Gleason <fredg@paravelsystems.com>
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -49,10 +47,10 @@ void Xport::AddCart()
   // Verify Post
   //
   if(!xport_post->getValue("GROUP_NAME",&group_name)) {
-    RDCgiError("Missing GROUP_NAME",400);
+    XmlExit("Missing GROUP_NAME",400);
   }
   if(!xport_post->getValue("TYPE",&type)) {
-    RDCgiError("Missing TYPE",400);
+    XmlExit("Missing TYPE",400);
   }
   if(type.lower()=="audio") {
     cart_type=RDCart::Audio;
@@ -62,7 +60,7 @@ void Xport::AddCart()
       cart_type=RDCart::Macro;
     }
     else {
-      RDCgiError("Invalid TYPE",400);
+      XmlExit("Invalid TYPE",400);
     }
   }
   xport_post->getValue("CART_NUMBER",&cart_number);
@@ -71,22 +69,22 @@ void Xport::AddCart()
   // Verify User Perms
   //
   if(!xport_user->groupAuthorized(group_name)) {
-    RDCgiError("No such group",404);
+    XmlExit("No such group",404);
   }
-  group=new RDGroup(group_name,this);
+  group=new RDGroup(group_name);
   if(cart_number==0) {
     if((cart_number=group->nextFreeCart())==0) {
       delete group;
-      RDCgiError("No free carts in group",500);
+      XmlExit("No free carts in group",500);
     }
   }
   if(!group->cartNumberValid(cart_number)) {
     delete group;
-    RDCgiError("Cart number out of range for group",401);
+    XmlExit("Cart number out of range for group",401);
   }
   delete group;
   if(!xport_user->createCarts()) {
-    RDCgiError("Unauthorized",401);
+    XmlExit("Unauthorized",401);
   }
 
   //
@@ -95,18 +93,18 @@ void Xport::AddCart()
   cart=new RDCart(cart_number);
   if(cart->exists()) {
     delete cart;
-    RDCgiError("Cart already exists",403);
+    XmlExit("Cart already exists",403);
   }
   if(!cart->create(group_name,cart_type)) {
     delete cart;
-    RDCgiError("Unable to create cart",500);
+    XmlExit("Unable to create cart",500);
   }
   printf("Content-type: application/xml\n");
   printf("Status: 200\n\n");
   printf("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n");
   printf("<cartAdd>\n");
   if(cart->exists()) {
-    printf("%s",(const char *)cart->xml(false));
+    printf("%s",(const char *)cart->xml(false,true));
   }
   delete cart;
   printf("</cartAdd>\n");
@@ -145,7 +143,7 @@ void Xport::ListCarts()
   // Generate Cart List
   //
   if(group_name.isEmpty()||(group_name==tr("ALL"))) {
-    where=RDAllCartSearchText(filter,xport_user->name());
+    where=RDAllCartSearchText(filter,"",xport_user->name(),false);
   }
   else {
     sql=QString().
@@ -156,9 +154,9 @@ void Xport::ListCarts()
     q=new RDSqlQuery(sql);
     if(!q->first()) {
       delete q;
-      RDCgiError("No such group",404);
+      XmlExit("No such group",404);
     }
-    where=RDCartSearchText(filter,group_name);
+    where=RDCartSearchText(filter,group_name,"",false);
   }
   if(cart_type!=RDCart::All) {
     where+=QString().sprintf("&&(TYPE=%u)",cart_type);
@@ -175,7 +173,7 @@ void Xport::ListCarts()
   printf("<cartList>\n");
   while(q->next()) {
     cart=new RDCart(q->value(0).toUInt());
-    printf("%s",(const char *)cart->xml(include_cuts));
+    printf("%s",(const char *)cart->xml(include_cuts,true));
     delete cart;
   }
   printf("</cartList>\n");
@@ -198,7 +196,7 @@ void Xport::ListCart()
   // Verify Post
   //
   if(!xport_post->getValue("CART_NUMBER",&cart_number)) {
-    RDCgiError("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400);
   }
   xport_post->getValue("INCLUDE_CUTS",&include_cuts);
 
@@ -206,7 +204,7 @@ void Xport::ListCart()
   // Verify User Perms
   //
   if(!xport_user->cartAuthorized(cart_number)) {
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
 
   //
@@ -217,7 +215,7 @@ void Xport::ListCart()
   printf("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n");
   printf("<cartList>\n");
   cart=new RDCart(cart_number);
-  printf("%s",(const char *)cart->xml(include_cuts));
+  printf("%s",(const char *)cart->xml(include_cuts,true));
   delete cart;
   printf("</cartList>\n");
 
@@ -229,6 +227,7 @@ void Xport::EditCart()
 {
   QString where="";
   RDCart *cart;
+  RDGroup *group;
   int cart_number;
   int include_cuts=0;
   QString group_name;
@@ -243,7 +242,7 @@ void Xport::EditCart()
   // Verify Post
   //
   if(!xport_post->getValue("CART_NUMBER",&cart_number)) {
-    RDCgiError("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400);
   }
   xport_post->getValue("INCLUDE_CUTS",&include_cuts);
 
@@ -251,15 +250,28 @@ void Xport::EditCart()
   // Verify User Perms
   //
   if(!xport_user->cartAuthorized(cart_number)) {
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
   if(!xport_user->modifyCarts()) {
-    RDCgiError("Unauthorized",401);
+    XmlExit("Unauthorized",401);
   }
   if(xport_post->getValue("GROUP_NAME",&group_name)) {
     if(!xport_user->groupAuthorized(group_name)) {
-      RDCgiError("No such group",404);
+      XmlExit("No such group",404);
     }
+    group=new RDGroup(group_name);
+    if(!group->exists()) {
+      delete group;
+      XmlExit("No such group",404);
+    }
+    if(group->enforceCartRange()) {
+      if(((unsigned)cart_number<group->defaultLowCart())||
+	 ((unsigned)cart_number>group->defaultHighCart())) {
+	delete group;
+	XmlExit("Invalid cart number for group",409);
+      }
+    }
+    delete group;
   }
 
   //
@@ -268,17 +280,17 @@ void Xport::EditCart()
   cart=new RDCart(cart_number);
   if(!cart->exists()) {
     delete cart;
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
   if(xport_post->getValue("FORCED_LENGTH",&value)) {
     number=RDSetTimeLength(value);
     if(cart->type()==RDCart::Macro) {
       delete cart;
-      RDCgiError("Unsupported operation for cart type",403);
+      XmlExit("Unsupported operation for cart type",403);
     }
     if(!cart->validateLengths(number)) {
       delete cart;
-      RDCgiError("Forced length out of range",403);
+      XmlExit("Forced length out of range",403);
     }
   }
   switch(cart->type()) {
@@ -291,7 +303,7 @@ void Xport::EditCart()
       value.stripWhiteSpace();
       if(value.right(1)!="!") {
 	delete cart;
-	RDCgiError("Invalid macro data",400);
+	XmlExit("Invalid macro data",400);
       }
       macro+=value;
     }
@@ -316,7 +328,7 @@ void Xport::EditCart()
   if(xport_post->getValue("YEAR",&value)) {
     number=value.toInt(&ok);
     if((ok)&&(number>0)) {
-      cart->setYear(QDate(number,0,0));
+      cart->setYear(number);
     }
   }
   if(xport_post->getValue("LABEL",&value)) {
@@ -378,7 +390,7 @@ void Xport::EditCart()
   printf("Status: 200\n\n");
   printf("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n");
   printf("<cartList>\n");
-  printf("%s",(const char *)cart->xml(include_cuts));
+  printf("%s",(const char *)cart->xml(include_cuts,true));
   delete cart;
   printf("</cartList>\n");
 
@@ -395,17 +407,17 @@ void Xport::RemoveCart()
   // Verify Post
   //
   if(!xport_post->getValue("CART_NUMBER",&cart_number)) {
-    RDCgiError("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400);
   }
 
   //
   // Verify User Perms
   //
   if(!xport_user->cartAuthorized(cart_number)) {
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
   if(!xport_user->deleteCarts()) {
-    RDCgiError("Unauthorized",401);
+    XmlExit("Unauthorized",401);
   }
 
   //
@@ -414,18 +426,14 @@ void Xport::RemoveCart()
   cart=new RDCart(cart_number);
   if(!cart->exists()) {
     delete cart;
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
-  if(!cart->remove(NULL,NULL)) {
+  if(!cart->remove(NULL,NULL,xport_config)) {
     delete cart;
-    RDCgiError("Unable to delete cart",500);
+    XmlExit("Unable to delete cart",500);
   }
-  printf("Content-type: text/html\n");
-  printf("Status: 200\n\n");
-  printf("OK\n");
   delete cart;
-
-  Exit(0);
+  XmlExit("OK",200);
 }
 
 
@@ -440,17 +448,17 @@ void Xport::AddCut()
   // Verify Post
   //
   if(!xport_post->getValue("CART_NUMBER",&cart_number)) {
-    RDCgiError("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400);
   }
 
   //
   // Verify User Perms
   //
   if(!xport_user->cartAuthorized(cart_number)) {
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
   if(!xport_user->editAudio()) {
-    RDCgiError("Unauthorized",401);
+    XmlExit("Unauthorized",401);
   }
 
   //
@@ -459,11 +467,11 @@ void Xport::AddCut()
   cart=new RDCart(cart_number);
   if(!cart->exists()) {
     delete cart;
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
   if((cut_number=cart->addCut(0,0,2))<0) {
     delete cart;
-    RDCgiError("No new cuts available",500);
+    XmlExit("No new cuts available",500);
   }
   printf("Content-type: application/xml\n");
   printf("Status: 200\n\n");
@@ -471,7 +479,7 @@ void Xport::AddCut()
   printf("<cutAdd>\n");
   cut=new RDCut(cart_number,cut_number);
   if(cut->exists()) {
-    printf("%s",(const char *)cut->xml());
+    printf("%s",(const char *)cut->xml(true));
   }
   delete cut;
   delete cart;
@@ -492,14 +500,14 @@ void Xport::ListCuts()
   // Verify Post
   //
   if(!xport_post->getValue("CART_NUMBER",&cart_number)) {
-    RDCgiError("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400);
   }
 
   //
   // Verify User Perms
   //
   if(!xport_user->cartAuthorized(cart_number)) {
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
 
   //
@@ -516,7 +524,7 @@ void Xport::ListCuts()
   while(q->next()) {
     cut=new RDCut(q->value(0).toString());
     if(cut->exists()) {
-      printf("%s",(const char *)cut->xml());
+      printf("%s",(const char *)cut->xml(true));
     }
     delete cut;
   }
@@ -537,17 +545,17 @@ void Xport::ListCut()
   // Verify Post
   //
   if(!xport_post->getValue("CART_NUMBER",&cart_number)) {
-    RDCgiError("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400);
   }
   if(!xport_post->getValue("CUT_NUMBER",&cut_number)) {
-    RDCgiError("Missing CUT_NUMBER",400);
+    XmlExit("Missing CUT_NUMBER",400);
   }
 
   //
   // Verify User Perms
   //
   if(!xport_user->cartAuthorized(cart_number)) {
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
 
   //
@@ -556,13 +564,13 @@ void Xport::ListCut()
   cut=new RDCut(cart_number,cut_number);
   if(!cut->exists()) {
     delete cut;
-    RDCgiError("No such cut",404);
+    XmlExit("No such cut",404);
   }
   printf("Content-type: application/xml\n");
   printf("Status: 200\n\n");
   printf("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n");
   printf("<cutList>\n");
-  printf("%s",(const char *)cut->xml());
+  printf("%s",(const char *)cut->xml(true));
   printf("</cutList>\n");
   delete cut;
 
@@ -581,35 +589,140 @@ void Xport::EditCut()
   QTime time;
   bool rotation_changed=false;
   bool length_changed=false;
+  QDateTime start_datetime;
+  bool use_start_datetime=false;
+  QDateTime end_datetime;
+  bool use_end_datetime=false;
+  QTime start_daypart;
+  bool use_start_daypart=false;
+  QTime end_daypart;
+  bool use_end_daypart=false;
+  int talk_points[2];
+  bool use_end_points[2]={false,false};
+  int end_points[2];
+  bool use_talk_points[2]={false,false};
+  int segue_points[2];
+  bool use_segue_points[2]={false,false};
+  int hook_points[2];
+  bool use_hook_points[2]={false,false};
+  int fadeup_point;
+  bool use_fadeup_point=false;
+  int fadedown_point;
+  bool use_fadedown_point=false;
+  bool use_weight=false;
+  int weight;
+  bool ok=false;
 
   //
   // Verify Post
   //
   if(!xport_post->getValue("CART_NUMBER",&cart_number)) {
-    RDCgiError("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400);
   }
   if(!xport_post->getValue("CUT_NUMBER",&cut_number)) {
-    RDCgiError("Missing CUT_NUMBER",400);
+    XmlExit("Missing CUT_NUMBER",400);
   }
 
   //
   // Verify User Perms
   //
   if(!xport_user->cartAuthorized(cart_number)) {
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
   if(!xport_user->editAudio()) {
-    RDCgiError("Unauthorized",401);
+    XmlExit("Unauthorized",401);
+  }
+
+  //
+  // Check Date/Time Values for Validity
+  //
+  if((use_start_datetime=xport_post->
+      getValue("START_DATETIME",&start_datetime,&ok))) {
+    if(!ok) {
+      XmlExit("invalid START_DATETIME",400);
+    }
+  }
+  if((use_end_datetime=xport_post->
+      getValue("END_DATETIME",&end_datetime,&ok))) {
+    if(!ok) {
+      XmlExit("invalid END_DATETIME",400);
+    }
+  }
+  if(use_start_datetime!=use_end_datetime) {
+    XmlExit("both DATETIME values must be set together",400);
+  }
+  if(use_start_datetime&&(start_datetime>end_datetime)) {
+    XmlExit("START_DATETIME is later than END_DATETIME",400);
+  }
+
+  if((use_start_daypart=xport_post->
+      getValue("START_DAYPART",&start_daypart,&ok))) {
+    if(!ok) {
+      XmlExit("invalid START_DAYPART",400);
+    }
+  }
+  if((use_end_daypart=xport_post->
+      getValue("END_DAYPART",&end_daypart,&ok))) {
+    if(!ok) {
+      XmlExit("invalid END_DAYPART",400);
+    }
+  }
+  if(use_start_daypart!=use_end_daypart) {
+    XmlExit("both DAYPART values must be set together",400);
+  }
+
+  cut=new RDCut(cart_number,cut_number);
+  if(!cut->exists()) {
+    delete cut;
+    XmlExit("No such cut",404);
+  }
+
+  //
+  // Check pointers for validity
+  //
+  end_points[0]=cut->startPoint();
+  end_points[1]=cut->endPoint();
+  fadeup_point=cut->fadeupPoint();
+  fadedown_point=cut->fadedownPoint();
+  CheckPointerValidity(end_points,use_end_points,"",0);
+  CheckPointerValidity(talk_points,use_talk_points,"TALK_",end_points[1]);
+  CheckPointerValidity(segue_points,use_segue_points,"SEGUE_",end_points[1]);
+  CheckPointerValidity(hook_points,use_hook_points,"HOOK_",end_points[1]);
+  if((use_fadeup_point=xport_post->
+      getValue("FADEUP_POINT",&fadeup_point,&ok))) {
+    if(!ok) {
+      XmlExit("invalid FADEUP_POINT",400);
+    }
+    if(fadeup_point>end_points[1]) {
+      XmlExit("FADEUP_POINT exceeds length of cart",400);
+    }
+  }
+  if((use_fadedown_point=xport_post->
+      getValue("FADEDOWN_POINT",&fadedown_point,&ok))) {
+    if(!ok) {
+      XmlExit("invalid FADEDOWN_POINT",400);
+    }
+    if(fadeup_point>end_points[1]) {
+      XmlExit("FADEDOWN_POINT exceeds length of cart",400);
+    }
+  }
+  if(use_fadeup_point&&use_fadedown_point&&
+     (fadeup_point>=0)&&(fadedown_point>=0)&&(fadeup_point>fadedown_point)) {
+    XmlExit("FADEUP_POINT is greater than FADEDOWN_POINT",400);
+  }
+
+  //
+  // Check Weight
+  //
+  if((use_weight=xport_post->getValue("WEIGHT",&weight,&ok))) {
+    if((!ok)||(weight<0)) {
+      XmlExit("invalid WEIGHT",400);
+    }
   }
 
   //
   // Process Request
   //
-  cut=new RDCut(cart_number,cut_number);
-  if(!cut->exists()) {
-    delete cut;
-    RDCgiError("No such cut",404);
-  }
   if(xport_post->getValue("EVERGREEN",&num)) {
     cut->setEvergreen(num);
     rotation_changed=true;
@@ -626,13 +739,13 @@ void Xport::EditCut()
   if(xport_post->getValue("ISCI",&str)) {
     cut->setIsci(str);
   }
-  if(xport_post->getValue("START_DATETIME",&datetime)) {
-    cut->setStartDatetime(datetime,!datetime.isNull());
+  if(use_start_datetime) {
+    cut->setStartDatetime(start_datetime,!start_datetime.isNull());
     length_changed=true;
     rotation_changed=true;
   }
-  if(xport_post->getValue("END_DATETIME",&datetime)) {
-    cut->setEndDatetime(datetime,!datetime.isNull());
+  if(use_end_datetime) {
+    cut->setEndDatetime(end_datetime,!end_datetime.isNull());
     length_changed=true;
     rotation_changed=true;
   }
@@ -664,56 +777,56 @@ void Xport::EditCut()
     cut->setWeekPart(7,num);
     rotation_changed=true;
   }
-  if(xport_post->getValue("START_DAYPART",&time)) {
-    cut->setStartDaypart(time,!time.isNull());
+  if(use_start_daypart) {
+    cut->setStartDaypart(start_daypart,!start_daypart.isNull());
     rotation_changed=true;
   }
-  if(xport_post->getValue("END_DAYPART",&time)) {
-    cut->setEndDaypart(time,!time.isNull());
+  if(use_end_daypart) {
+    cut->setEndDaypart(end_daypart,!end_daypart.isNull());
     rotation_changed=true;
   }
-  if(xport_post->getValue("WEIGHT",&num)) {
-    cut->setWeight(num);
+  if(use_weight) {
+    cut->setWeight(weight);
     rotation_changed=true;
   }
-  if(xport_post->getValue("START_POINT",&num)) {
-    cut->setStartPoint(num);
+  if(use_end_points[0]) {
+    cut->setStartPoint(end_points[0]);
     length_changed=true;
   }
-  if(xport_post->getValue("END_POINT",&num)) {
-    cut->setEndPoint(num);
+  if(use_end_points[1]) {
+    cut->setEndPoint(end_points[1]);
     length_changed=true;
   }
-  if(xport_post->getValue("FADEUP_POINT",&num)) {
-    cut->setFadeupPoint(num);
+  if(use_fadeup_point) {
+    cut->setFadeupPoint(fadeup_point);
     length_changed=true;
   }
-  if(xport_post->getValue("FADEDOWN_POINT",&num)) {
-    cut->setFadedownPoint(num);
+  if(use_fadedown_point) {
+    cut->setFadedownPoint(fadedown_point);
     length_changed=true;
   }
-  if(xport_post->getValue("SEGUE_START_POINT",&num)) {
-    cut->setSegueStartPoint(num);
+  if(use_segue_points[0]) {
+    cut->setSegueStartPoint(segue_points[0]);
     length_changed=true;
   }
-  if(xport_post->getValue("SEGUE_END_POINT",&num)) {
-    cut->setSegueEndPoint(num);
+  if(use_segue_points[1]) {
+    cut->setSegueEndPoint(segue_points[1]);
     length_changed=true;
   }
-  if(xport_post->getValue("HOOK_START_POINT",&num)) {
-    cut->setHookStartPoint(num);
+  if(use_hook_points[0]) {
+    cut->setHookStartPoint(hook_points[0]);
     length_changed=true;
   }
-  if(xport_post->getValue("HOOK_END_POINT",&num)) {
-    cut->setHookEndPoint(num);
+  if(use_hook_points[1]) {
+    cut->setHookEndPoint(hook_points[1]);
     length_changed=true;
   }
-  if(xport_post->getValue("TALK_START_POINT",&num)) {
-    cut->setTalkStartPoint(num);
+  if(use_talk_points[0]) {
+    cut->setTalkStartPoint(talk_points[0]);
     length_changed=true;
   }
-  if(xport_post->getValue("TALK_END_POINT",&num)) {
-    cut->setTalkEndPoint(num);
+  if(use_talk_points[1]) {
+    cut->setTalkEndPoint(talk_points[1]);
     length_changed=true;
   }
   if(length_changed||rotation_changed) {
@@ -726,16 +839,64 @@ void Xport::EditCut()
     }
     delete cart;
   }
-
-  printf("Content-type: text/html\n");
+  printf("Content-type: application/xml\n");
   printf("Status: 200\n\n");
-  printf("OK\n");
+  printf("<?xml version=\"1.0\" encoding=\"UTF-8\" ?>\n");
+  printf("<cutList>\n");
+  printf("%s",(const char *)cut->xml(true));
+  printf("</cutList>\n");
   delete cut;
 
   Exit(0);
 }
 
 
+void Xport::CheckPointerValidity(int ptr_values[2],bool use_ptrs[2],
+                                const QString &type,unsigned max_value)
+{
+  bool start_ok=false;
+  bool end_ok=false;
+
+  use_ptrs[0]=xport_post->getValue(type+"START_POINT",&ptr_values[0],&start_ok);
+  use_ptrs[1]=xport_post->getValue(type+"END_POINT",&ptr_values[1],&end_ok);
+  if((!use_ptrs[0])&&(!use_ptrs[1])) {
+    return;
+  }
+  if(!start_ok) {
+    XmlExit("invalid "+type+"START_POINT",400);
+  }
+  if(!end_ok) {
+    XmlExit("invalid "+type+"END_POINT",400);
+  }
+  if(use_ptrs[0]!=use_ptrs[1]) {
+    XmlExit("both "+type+"*_POINT values must be set together",400);
+  }
+  if(use_ptrs[0]) {
+    if(((ptr_values[0]<0)&&(ptr_values[1]>=0))||
+       ((ptr_values[0]>=0)&&(ptr_values[1]<0))) {
+      XmlExit("inconsistent "+type+"*_POINT values",400);
+    }
+  }
+  if(ptr_values[0]>=0) {
+    if(ptr_values[0]>ptr_values[1]) {
+      XmlExit(type+"START_POINT greater than "+type+"END_POINT",400);
+    }
+    if((max_value>0)&&((unsigned)ptr_values[1]>max_value)) {
+      XmlExit(type+"END_POINT exceeds length of cut",400);
+    }
+  }
+  else {
+    if(max_value==0) {
+      XmlExit("End markers cannot be removed",400);
+    }
+    else {
+      ptr_values[0]=-1;
+      ptr_values[1]=-1;
+    }
+  }
+}
+
+
 void Xport::RemoveCut()
 {
   RDCart *cart;
@@ -746,20 +907,20 @@ void Xport::RemoveCut()
   // Verify Post
   //
   if(!xport_post->getValue("CART_NUMBER",&cart_number)) {
-    RDCgiError("Missing CART_NUMBER",400);
+    XmlExit("Missing CART_NUMBER",400);
   }
   if(!xport_post->getValue("CUT_NUMBER",&cut_number)) {
-    RDCgiError("Missing CUT_NUMBER",400);
+    XmlExit("Missing CUT_NUMBER",400);
   }
 
   //
   // Verify User Perms
   //
   if(!xport_user->cartAuthorized(cart_number)) {
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
   if(!xport_user->editAudio()) {
-    RDCgiError("Unauthorized",401);
+    XmlExit("Unauthorized",401);
   }
 
   //
@@ -768,16 +929,13 @@ void Xport::RemoveCut()
   cart=new RDCart(cart_number);
   if(!cart->exists()) {
     delete cart;
-    RDCgiError("No such cart",404);
+    XmlExit("No such cart",404);
   }
-  if(!cart->removeCut(NULL,NULL,RDCut::cutName(cart_number,cut_number))) {
+  if(!cart->removeCut(NULL,NULL,RDCut::cutName(cart_number,cut_number),
+		      xport_config)) {
     delete cart;
-    RDCgiError("No such cut",404);
+    XmlExit("No such cut",404);
   }
-  printf("Content-type: text/html\n");
-  printf("Status: 200\n\n");
-  printf("OK\n");
   delete cart;
-
-  Exit(0);
+  XmlExit("OK",200);
 }
